package androidx.appcompat.app;

import X6FRs_4.KQgRr5e_0.XnFJ5_9;
import X6FRs_4.KQgRr5e_0.YghfZG_14.QxJ9d_1;
import android.content.Context;
import android.content.res.Configuration;
import android.content.res.TypedArray;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.KeyEvent;
import android.view.View;
import android.view.ViewGroup;
/* loaded from: classes.dex */
public abstract class ActionBar {

    /* loaded from: classes.dex */
    public interface KQgRr5e_0 {
        void KQgRr5e_0(boolean z);
    }

    @Deprecated
    /* loaded from: classes.dex */
    public static abstract class QxJ9d_1 {
        public abstract Drawable KQgRr5e_0();

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public abstract View m822KQgRr5e_0();

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public abstract CharSequence m823KQgRr5e_0();

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public abstract void m824KQgRr5e_0();

        public abstract CharSequence QxJ9d_1();
    }

    public void IFxWkV_5() {
    }

    public abstract void IMuAHx_6();

    public abstract int KQgRr5e_0();

    public X6FRs_4.KQgRr5e_0.YghfZG_14.QxJ9d_1 KQgRr5e_0(QxJ9d_1.KQgRr5e_0 kQgRr5e_0) {
        return null;
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public abstract Context m820KQgRr5e_0();

    public void KQgRr5e_0(Configuration configuration) {
    }

    public abstract void KQgRr5e_0(CharSequence charSequence);

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public boolean m821KQgRr5e_0() {
        return false;
    }

    public abstract boolean KQgRr5e_0(int i, KeyEvent keyEvent);

    public boolean KQgRr5e_0(KeyEvent keyEvent) {
        return false;
    }

    public abstract void Mqv2r_3(boolean z);

    public boolean Mqv2r_3() {
        return false;
    }

    public abstract void PGPF6hQ_2(boolean z);

    public boolean PGPF6hQ_2() {
        return false;
    }

    public abstract void QxJ9d_1(boolean z);

    public abstract boolean QxJ9d_1();

    public abstract void X6FRs_4();

    public abstract void X6FRs_4(boolean z);

    /* loaded from: classes.dex */
    public static class LayoutParams extends ViewGroup.MarginLayoutParams {
        public int KQgRr5e_0;

        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
            this.KQgRr5e_0 = 0;
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, XnFJ5_9.ActionBarLayout);
            this.KQgRr5e_0 = obtainStyledAttributes.getInt(XnFJ5_9.ActionBarLayout_android_layout_gravity, 0);
            obtainStyledAttributes.recycle();
        }

        public LayoutParams(int i, int i2) {
            super(i, i2);
            this.KQgRr5e_0 = 0;
            this.KQgRr5e_0 = 8388627;
        }

        public LayoutParams(LayoutParams layoutParams) {
            super((ViewGroup.MarginLayoutParams) layoutParams);
            this.KQgRr5e_0 = 0;
            this.KQgRr5e_0 = layoutParams.KQgRr5e_0;
        }

        public LayoutParams(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
            this.KQgRr5e_0 = 0;
        }
    }
}
